@@ -1,4 +1,3 @@
-
 from __future__ import annotations
 from .configs import *
 from . import shared as td
@@ -8,10 +7,11 @@ import hashlib
 # if TYPE_CHECKING:
 #     from ..opentele import *
 
+
 class AuthKeyType(IntEnum):
     """
     Type of `AuthKey`
-    
+
     ### Attributes:
         Generated (`IntEnum`):
             Generated key
@@ -25,10 +25,12 @@ class AuthKeyType(IntEnum):
         Local (`IntEnum`):
             Local key
     """
-    Generated       = 0
-    Temporary       = 1
-    ReadFromFile    = 2
-    Local           = 3
+
+    Generated = 0
+    Temporary = 1
+    ReadFromFile = 2
+    Local = 3
+
 
 class AuthKey(BaseObject):
     """
@@ -38,7 +40,7 @@ class AuthKey(BaseObject):
     ### Attributes:
         DcId (DcId):
             Data Center ID (from 1 to 5).
-            
+
         type (AuthKeyType):
             Type of the key.
 
@@ -48,12 +50,13 @@ class AuthKey(BaseObject):
     """
 
     kSize = 256
-    def __init__(self, key : bytes = bytes(), type : AuthKeyType = AuthKeyType.Generated, dcId : DcId = DcId.Invalid) -> None: # type: ignore
+
+    def __init__(self, key: bytes = bytes(), type: AuthKeyType = AuthKeyType.Generated, dcId: DcId = DcId.Invalid) -> None:  # type: ignore
         self.__type = type
         self.__dcId = dcId
         self.__key = key
         # if (type == self.Type.Generated) or (type == self.Type.Temporary):
-            # self.__creationtime = ...
+        # self.__creationtime = ...
         self.__countKeyId()
 
     @property
@@ -67,27 +70,39 @@ class AuthKey(BaseObject):
     @property
     def key(self) -> bytes:
         return self.__key
-    
-    def write(self, to : QDataStream) -> None:
+
+    def write(self, to: QDataStream) -> None:
         to.writeRawData(self.key)
 
     def __countKeyId(self) -> None:
         hash = hashlib.sha1(self.__key).digest()
-        self.__keyId = int.from_bytes(hash[12:12+8], 'little')
-    
-    def prepareAES_oldmtp(self, msgKey : bytes, send : bool) -> typing.Tuple[bytes, bytes]:
-        x = 0 if send else 8
-        sha1_a = hashlib.sha1(msgKey[:16] + self.__key[x : x+32]).digest()
-        sha1_b = hashlib.sha1(self.__key[x+32 : x+32+16] + msgKey[:16] + self.__key[x+48 : x+48+16]).digest()
-        sha1_c = hashlib.sha1(self.__key[x+64 : x+64+32] + msgKey[:16]).digest()
-        sha1_d = hashlib.sha1(msgKey[:16] + self.__key[x+96 : x+96+32]).digest()
+        self.__keyId = int.from_bytes(hash[12 : 12 + 8], "little")
 
-        aesKey = sha1_a[:8] + sha1_b[8:8+12] + sha1_c[4:4+12]
-        aesIv = sha1_a[8:8+12] + sha1_b[:8] + sha1_c[16:16+4] + sha1_d[:8]
+    def prepareAES_oldmtp(
+        self, msgKey: bytes, send: bool
+    ) -> typing.Tuple[bytes, bytes]:
+        x = 0 if send else 8
+        sha1_a = hashlib.sha1(msgKey[:16] + self.__key[x : x + 32]).digest()
+
+        sha1_b = hashlib.sha1(
+            self.__key[x + 32 : x + 32 + 16]
+            + msgKey[:16]
+            + self.__key[x + 48 : x + 48 + 16]
+        ).digest()
+
+        sha1_c = hashlib.sha1(self.__key[x + 64 : x + 64 + 32] + msgKey[:16]).digest()
+        sha1_d = hashlib.sha1(msgKey[:16] + self.__key[x + 96 : x + 96 + 32]).digest()
+
+        aesKey = sha1_a[:8] + sha1_b[8 : 8 + 12] + sha1_c[4 : 4 + 12]
+        aesIv = sha1_a[8 : 8 + 12] + sha1_b[:8] + sha1_c[16 : 16 + 4] + sha1_d[:8]
 
         return aesKey, aesIv
 
     @staticmethod
-    def FromStream(stream : QDataStream, type : AuthKeyType = AuthKeyType.ReadFromFile, dcId : DcId = DcId(0)) -> AuthKey:
+    def FromStream(
+        stream: QDataStream,
+        type: AuthKeyType = AuthKeyType.ReadFromFile,
+        dcId: DcId = DcId(0),
+    ) -> AuthKey:
         keyData = stream.readRawData(AuthKey.kSize)
-        return AuthKey(keyData, type, dcId)
\ No newline at end of file
+        return AuthKey(keyData, type, dcId)
