@@ -4,61 +4,63 @@ from .configs import *
 from . import shared as td
 
 
-
-
 class MTP(BaseObject):
-    '''
+    """
     [MTProto Protocal](https://core.telegram.org/mtproto)
 
     This class is for further future developments and has no usage for now.
-    
+
     ### Attributes:
         `Environment` (`class`): MTP Enviroment
         `RSAPublicKey` (`class`): RSAPublicKey
         `DcOptions` (`class`): DcOptions
         `ConfigFields` (`class`): ConfigFields
         `Config` (`class`): Config
-    '''
-
+    """
 
     class Environment(IntEnum):
-        '''
+        """
         Enviroment flag for MTP.Config
         ### Attributes:
             Production (`IntEnum`): Production Enviroment
             Test (`IntEnum`): Test Enviroment
-        '''
+        """
+
         Production = 0
         Test = 1
-    
+
     class RSAPublicKey(BaseObject):
-        '''
+        """
         To be added
-        '''
-    
+        """
+
     class DcOptions(BaseObject):
-        '''
+        """
         Data Center Options, providing information about DC ip, port,.. etc
-        '''
-        
+        """
+
         kVersion = 2
 
-        def __init__(self, enviroment : MTP.Environment) -> None:
+        def __init__(self, enviroment: MTP.Environment) -> None:
             self._enviroment = enviroment
-            self._publicKeys : typing.Dict[DcId, MTP.RSAPublicKey] = {}
-            self._cdnPublicKeys : typing.Dict[DcId, MTP.RSAPublicKey] = {}
-            self._data : typing.Dict[DcId, typing.List[MTP.DcOptions.Endpoint]] = {}
+            self._publicKeys: typing.Dict[DcId, MTP.RSAPublicKey] = {}
+            self._cdnPublicKeys: typing.Dict[DcId, MTP.RSAPublicKey] = {}
+            self._data: typing.Dict[DcId, typing.List[MTP.DcOptions.Endpoint]] = {}
 
             self.constructFromBuiltIn()
 
         def isTestMode(self):
             return self._enviroment != MTP.Environment.Production
-        
-        def constructAddOne(self, id : DcId, flags : MTP.DcOptions.Flag, ip : str, port : int, secret : bytes):
+
+        def constructAddOne(
+            self, id: DcId, flags: MTP.DcOptions.Flag, ip: str, port: int, secret: bytes
+        ):
             self.applyOneGuarded(DcId.BareDcId(id), flags, ip, port, secret)
 
-        def applyOneGuarded(self, id : DcId, flags : MTP.DcOptions.Flag, ip : str, port : int, secret : bytes):
-    
+        def applyOneGuarded(
+            self, id: DcId, flags: MTP.DcOptions.Flag, ip: str, port: int, secret: bytes
+        ):
+
             if not id in self._data:
                 self._data[id] = []
             else:
@@ -69,31 +71,31 @@ class MTP(BaseObject):
 
             endpoint = MTP.DcOptions.Endpoint(id, flags, ip, port, bytes())
             self._data[id].append(endpoint)
-            
+
         def constructFromBuiltIn(self) -> None:
 
             # TO BE ADDED
             # self.readBuiltInPublicKeys()
 
-            def addToData(dcs : List[BuiltInDc], flags : MTP.DcOptions.Flag):
+            def addToData(dcs: List[BuiltInDc], flags: MTP.DcOptions.Flag):
 
                 for dc in dcs:
                     self.applyOneGuarded(dc.id, flags, dc.ip, dc.port, bytes())
 
             if self.isTestMode():
-                addToData(BuiltInDc.kBuiltInDcsTest, MTP.DcOptions.Flag.f_static | 0) # type: ignore
-                addToData(BuiltInDc.kBuiltInDcsIPv6Test, MTP.DcOptions.Flag.f_static | MTP.DcOptions.Flag.f_ipv6) # type: ignore
+                addToData(BuiltInDc.kBuiltInDcsTest, MTP.DcOptions.Flag.f_static | 0)  # type: ignore
+                addToData(BuiltInDc.kBuiltInDcsIPv6Test, MTP.DcOptions.Flag.f_static | MTP.DcOptions.Flag.f_ipv6)  # type: ignore
             else:
-                addToData(BuiltInDc.kBuiltInDcs, MTP.DcOptions.Flag.f_static | 0) # type: ignore
-                addToData(BuiltInDc.kBuiltInDcsIPv6, MTP.DcOptions.Flag.f_static | MTP.DcOptions.Flag.f_ipv6) # type: ignore
-            
-        def constructFromSerialized(self, serialized : QByteArray):
+                addToData(BuiltInDc.kBuiltInDcs, MTP.DcOptions.Flag.f_static | 0)  # type: ignore
+                addToData(BuiltInDc.kBuiltInDcsIPv6, MTP.DcOptions.Flag.f_static | MTP.DcOptions.Flag.f_ipv6)  # type: ignore
+
+        def constructFromSerialized(self, serialized: QByteArray):
             stream = QDataStream(serialized)
             stream.setVersion(QDataStream.Version.Qt_5_1)
 
             minusVersion = stream.readInt32()
             version = (-minusVersion) if (minusVersion < 0) else 0
-            
+
             count = stream.readInt32() if version > 0 else minusVersion
 
             self._data.clear()
@@ -105,19 +107,25 @@ class MTP(BaseObject):
                 ipSize = stream.readInt32()
 
                 kMaxIpSize = 45
-                Expects(condition=((ipSize > 0) and (ipSize <= kMaxIpSize)),
-                        exception=TDataBadConfigData("Bad ipSize data"))
+                Expects(
+                    condition=((ipSize > 0) and (ipSize <= kMaxIpSize)),
+                    exception=TDataBadConfigData("Bad ipSize data"),
+                )
 
                 ip = stream.readRawData(ipSize).decode("ascii")
 
                 kMaxSecretSize = 32
                 secret = bytes()
-                if (version > 0):
+                if version > 0:
                     secretSize = stream.readInt32()
-                    
-                    Expects(condition=((secretSize >= 0) and (secretSize <= kMaxSecretSize)),
-                            exception=TDataBadConfigData("Bad secretSize data"))
-                    
+
+                    Expects(
+                        condition=(
+                            (secretSize >= 0) and (secretSize <= kMaxSecretSize)
+                        ),
+                        exception=TDataBadConfigData("Bad secretSize data"),
+                    )
+
                     if secretSize > 0:
                         secret = stream.readRawData(secretSize)
 
@@ -129,7 +137,7 @@ class MTP(BaseObject):
             # Read CDN config
 
         def Serialize(self) -> QByteArray:
-            
+
             optionsCount = 0
             for dcId, endpoints in self._data.items():
                 if DcId.BareDcId(dcId) > 1000:
@@ -140,9 +148,9 @@ class MTP(BaseObject):
             stream = QDataStream(result, QIODevice.OpenModeFlag.WriteOnly)
             stream.setVersion(QDataStream.Version.Qt_5_1)
 
-            stream.writeInt32(-MTP.DcOptions.kVersion) # -2
-            
-		    # Dc options.
+            stream.writeInt32(-MTP.DcOptions.kVersion)  # -2
+
+            # Dc options.
             stream.writeInt32(optionsCount)
             for dcId, endpoints in self._data.items():
                 if DcId.BareDcId(dcId) > 1000:
@@ -158,7 +166,7 @@ class MTP(BaseObject):
 
                     stream.writeInt32(len(endpoint.secret))
                     stream.writeRawData(endpoint.secret)
-            
+
             # CDN public keys.
             # TO BE ADDED
             publicKeys = []
@@ -172,35 +180,34 @@ class MTP(BaseObject):
 
             return result
 
-
-
-        
         class Address(int):
-            '''
+            """
             Connection flag used for MTP.DcOptions.Endpoint
-            
+
             ### Attributes:
                 IPv4 (`int`): IPv4 connection
                 IPv6 (`int`): IPv6 connection
-            '''
+            """
+
             IPv4 = 0
             IPv6 = 1
 
         class Protocol(int):
-            '''
+            """
             Protocal flag used for MTP.DcOptions.Endpoint
-            
+
             ### Attributes:
                 Tcp (`int`): Tcp connection
                 Http (`int`): Http connection
-            '''
+            """
+
             Tcp = 0
             Http = 1
 
         class Flag(int):
-            '''
+            """
             Flag used for MTP.DcOptions.Endpoint
-            
+
             ### Attributes:
                 f_ipv6 (`int`): f_ipv6
                 f_media_only (`int`): f_media_only
@@ -209,7 +216,8 @@ class MTP(BaseObject):
                 f_static (`int`): f_static
                 f_secret (`int`): f_secret
                 MAX_FIELD (`int`): MAX_FIELD
-            '''
+            """
+
             f_ipv6 = 1 << 0
             f_media_only = 1 << 1
             f_tcpo_only = 1 << 2
@@ -219,7 +227,7 @@ class MTP(BaseObject):
             MAX_FIELD = 1 << 10
 
         class Endpoint(BaseObject):
-            '''
+            """
             Data center endpoint
 
             ### Attributes:
@@ -228,17 +236,24 @@ class MTP(BaseObject):
                 ip (`str`): IP address of the data center
                 port (`int`): Port to connect to
                 secret (`bytes`): secret
-            '''
-            def __init__(self, id : int, flags : MTP.DcOptions.Flag, ip : str, port : int, secret : bytes) -> None:
+            """
+
+            def __init__(
+                self,
+                id: int,
+                flags: MTP.DcOptions.Flag,
+                ip: str,
+                port: int,
+                secret: bytes,
+            ) -> None:
                 self.id = id
                 self.flags = flags
                 self.ip = ip
                 self.port = port
                 self.secret = secret
-                
-                
+
     class ConfigFields(BaseObject):
-        '''
+        """
         Configuration data for `MTP.Config`
 
         ### Attributes:
@@ -272,7 +287,8 @@ class MTP(BaseObject):
             phoneCallsEnabled (`bool`): `True`
             blockedMode (`bool`): `False`
             captionLengthMax (`int`): `1024`
-        '''
+        """
+
         def __init__(self) -> None:
             self.chatSizeMax = 200
             self.megagroupSizeMax = 10000
@@ -280,7 +296,7 @@ class MTP(BaseObject):
             self.onlineUpdatePeriod = 120000
             self.offlineBlurTimeout = 5000
             self.offlineIdleTimeout = 30000
-            self.onlineFocusTimeout = 1000 # Not from the server config.
+            self.onlineFocusTimeout = 1000  # Not from the server config.
             self.onlineCloudTimeout = 300000
             self.notifyCloudDelay = 30000
             self.notifyDefaultDelay = 1500
@@ -304,23 +320,30 @@ class MTP(BaseObject):
             self.phoneCallsEnabled = True
             self.blockedMode = False
             self.captionLengthMax = 1024
-        
+
     class Config(BaseObject):
-        '''
+        """
         Configuration of MTProto
         ### Attributes:
             kVersion (`int`): `1`
-        '''
-        
+        """
+
         kVersion = 1
 
-        def __init__(self, enviroment : MTP.Environment) -> None:
+        def __init__(self, enviroment: MTP.Environment) -> None:
             self._dcOptions = MTP.DcOptions(enviroment)
             self._fields = MTP.ConfigFields()
             self._fields.webFileDcId = 2 if self._dcOptions.isTestMode() else 4
-            self._fields.txtDomainString =  "tapv3.stel.com" if self._dcOptions.isTestMode() else "apv3.stel.com"
+            self._fields.txtDomainString = (
+                "tapv3.stel.com" if self._dcOptions.isTestMode() else "apv3.stel.com"
+            )
 
-        def endpoints(self, dcId : DcId = DcId._0) -> Dict[MTP.DcOptions.Address, Dict[MTP.DcOptions.Protocol, List[MTP.DcOptions.Endpoint]]]:
+        def endpoints(
+            self, dcId: DcId = DcId._0
+        ) -> Dict[
+            MTP.DcOptions.Address,
+            Dict[MTP.DcOptions.Protocol, List[MTP.DcOptions.Endpoint]],
+        ]:
 
             endpoints = self._dcOptions._data[dcId]
 
@@ -329,9 +352,9 @@ class MTP(BaseObject):
             Flag = MTP.DcOptions.Flag
             Endpoint = MTP.DcOptions.Endpoint
 
-            results : Dict[Address, Dict[Protocol, List[Endpoint]]] = {}
-            results[Address.IPv4] = {Protocol.Tcp : [], Protocol.Http : []} # type: ignore
-            results[Address.IPv6] = {Protocol.Tcp : [], Protocol.Http : []} # type: ignore
+            results: Dict[Address, Dict[Protocol, List[Endpoint]]] = {}
+            results[Address.IPv4] = {Protocol.Tcp: [], Protocol.Http: []}  # type: ignore
+            results[Address.IPv6] = {Protocol.Tcp: [], Protocol.Http: []}  # type: ignore
 
             for endpoint in endpoints:
 
@@ -339,11 +362,11 @@ class MTP(BaseObject):
 
                     flags = endpoint.flags
                     address = Address.IPv6 if (flags & Flag.f_ipv6) else Address.IPv4
-                    results[address][Protocol.Tcp].append(endpoint) # type: ignore
+                    results[address][Protocol.Tcp].append(endpoint)  # type: ignore
+
+                    if not (flags & (Flag.f_tcpo_only | Flag.f_secret)):
+                        results[address][Protocol.Http].append(endpoint)  # type: ignore
 
-                    if ( not (flags & (Flag.f_tcpo_only | Flag.f_secret))):
-                        results[address][Protocol.Http].append(endpoint) # type: ignore
-            
             return results
 
         def Serialize(self) -> QByteArray:
@@ -359,10 +382,14 @@ class MTP(BaseObject):
             stream.setVersion(QDataStream.Version.Qt_5_1)
 
             stream.writeInt32(MTP.Config.kVersion)
-            stream.writeInt32(MTP.Environment.Test if self._dcOptions.isTestMode() else MTP.Environment.Production)
-            
+            stream.writeInt32(
+                MTP.Environment.Test
+                if self._dcOptions.isTestMode()
+                else MTP.Environment.Production
+            )
+
             stream << options
-            
+
             stream.writeInt32(self._fields.chatSizeMax)
             stream.writeInt32(self._fields.megagroupSizeMax)
             stream.writeInt32(self._fields.forwardedCountMax)
@@ -398,67 +425,66 @@ class MTP(BaseObject):
 
             return result
 
-
-
         @staticmethod
-        def FromSerialized(serialized : QByteArray) -> MTP.Config:
-            
+        def FromSerialized(serialized: QByteArray) -> MTP.Config:
+
             stream = QDataStream(serialized)
             stream.setVersion(QDataStream.Version.Qt_5_1)
 
             version = stream.readInt32()
-            Expects(version == MTP.Config.kVersion, "version != kVersion, something went wrong")
-            
+            Expects(
+                version == MTP.Config.kVersion,
+                "version != kVersion, something went wrong",
+            )
+
             enviroment = MTP.Environment(stream.readInt32())
             result = MTP.Config(enviroment)
 
-                        
-            def read(field : _T) -> _T:
+            def read(field: _T) -> _T:
                 vtype = type(field)
-                if (vtype == int):
-                    return stream.readInt32() # type: ignore
-                elif (vtype == bool):
-                    return stream.readInt32() == 1 # type: ignore
-                elif (vtype == str):
-                    return stream.readQString() # type: ignore
-                
+                if vtype == int:
+                    return stream.readInt32()  # type: ignore
+                elif vtype == bool:
+                    return stream.readInt32() == 1  # type: ignore
+                elif vtype == str:
+                    return stream.readQString()  # type: ignore
+
                 raise ValueError()
-                
-                    
+
             dcOptionsSerialized = QByteArray()
             stream >> dcOptionsSerialized
 
             fileds = result._fields
-            fileds.chatSizeMax              = read(fileds.chatSizeMax)
-            fileds.megagroupSizeMax         = read(fileds.megagroupSizeMax)
-            fileds.forwardedCountMax        = read(fileds.forwardedCountMax)
-            fileds.onlineUpdatePeriod       = read(fileds.onlineUpdatePeriod)
-            fileds.offlineBlurTimeout       = read(fileds.offlineBlurTimeout)
-            fileds.offlineIdleTimeout       = read(fileds.offlineIdleTimeout)
-            fileds.onlineFocusTimeout       = read(fileds.onlineFocusTimeout)
-            fileds.onlineCloudTimeout       = read(fileds.onlineCloudTimeout)
-            fileds.notifyCloudDelay         = read(fileds.notifyCloudDelay)
-            fileds.notifyDefaultDelay       = read(fileds.notifyDefaultDelay)
-            fileds.savedGifsLimit           = read(fileds.savedGifsLimit)
-            fileds.editTimeLimit            = read(fileds.editTimeLimit)
-            fileds.revokeTimeLimit          = read(fileds.revokeTimeLimit)
-            fileds.revokePrivateTimeLimit   = read(fileds.revokePrivateTimeLimit)
-            fileds.revokePrivateInbox       = read(fileds.revokePrivateInbox)
-            fileds.stickersRecentLimit      = read(fileds.stickersRecentLimit)
-            fileds.stickersFavedLimit       = read(fileds.stickersFavedLimit)
-            fileds.pinnedDialogsCountMax    = read(fileds.pinnedDialogsCountMax)
+            fileds.chatSizeMax = read(fileds.chatSizeMax)
+            fileds.megagroupSizeMax = read(fileds.megagroupSizeMax)
+            fileds.forwardedCountMax = read(fileds.forwardedCountMax)
+            fileds.onlineUpdatePeriod = read(fileds.onlineUpdatePeriod)
+            fileds.offlineBlurTimeout = read(fileds.offlineBlurTimeout)
+            fileds.offlineIdleTimeout = read(fileds.offlineIdleTimeout)
+            fileds.onlineFocusTimeout = read(fileds.onlineFocusTimeout)
+            fileds.onlineCloudTimeout = read(fileds.onlineCloudTimeout)
+            fileds.notifyCloudDelay = read(fileds.notifyCloudDelay)
+            fileds.notifyDefaultDelay = read(fileds.notifyDefaultDelay)
+            fileds.savedGifsLimit = read(fileds.savedGifsLimit)
+            fileds.editTimeLimit = read(fileds.editTimeLimit)
+            fileds.revokeTimeLimit = read(fileds.revokeTimeLimit)
+            fileds.revokePrivateTimeLimit = read(fileds.revokePrivateTimeLimit)
+            fileds.revokePrivateInbox = read(fileds.revokePrivateInbox)
+            fileds.stickersRecentLimit = read(fileds.stickersRecentLimit)
+            fileds.stickersFavedLimit = read(fileds.stickersFavedLimit)
+            fileds.pinnedDialogsCountMax = read(fileds.pinnedDialogsCountMax)
             fileds.pinnedDialogsInFolderMax = read(fileds.pinnedDialogsInFolderMax)
-            fileds.internalLinksDomain      = read(fileds.internalLinksDomain)
-            fileds.channelsReadMediaPeriod  = read(fileds.channelsReadMediaPeriod)
-            fileds.callReceiveTimeoutMs     = read(fileds.callReceiveTimeoutMs)
-            fileds.callRingTimeoutMs        = read(fileds.callRingTimeoutMs)
-            fileds.callConnectTimeoutMs     = read(fileds.callConnectTimeoutMs)
-            fileds.callPacketTimeoutMs      = read(fileds.callPacketTimeoutMs)
-            fileds.webFileDcId              = read(fileds.webFileDcId)
-            fileds.txtDomainString          = read(fileds.txtDomainString)
-            fileds.phoneCallsEnabled        = read(fileds.phoneCallsEnabled)
-            fileds.blockedMode              = read(fileds.blockedMode)
-            fileds.captionLengthMax         = read(fileds.captionLengthMax)
+            fileds.internalLinksDomain = read(fileds.internalLinksDomain)
+            fileds.channelsReadMediaPeriod = read(fileds.channelsReadMediaPeriod)
+            fileds.callReceiveTimeoutMs = read(fileds.callReceiveTimeoutMs)
+            fileds.callRingTimeoutMs = read(fileds.callRingTimeoutMs)
+            fileds.callConnectTimeoutMs = read(fileds.callConnectTimeoutMs)
+            fileds.callPacketTimeoutMs = read(fileds.callPacketTimeoutMs)
+            fileds.webFileDcId = read(fileds.webFileDcId)
+            fileds.txtDomainString = read(fileds.txtDomainString)
+            fileds.phoneCallsEnabled = read(fileds.phoneCallsEnabled)
+            fileds.blockedMode = read(fileds.blockedMode)
+            fileds.captionLengthMax = read(fileds.captionLengthMax)
 
             # print(fileds.chatSizeMax)
             # print(fileds.megagroupSizeMax)
@@ -494,6 +520,3 @@ class MTP(BaseObject):
             ExpectStreamStatus(stream, "Could not stream MtpData serialized")
             result._dcOptions.constructFromSerialized(dcOptionsSerialized)
             return result
-        
-
-
